from edc_adverse_event.model_mixins import AeTmgModelMixin
from edc_model.models import BaseUuidModel


class AeTmg(AeTmgModelMixin, BaseUuidModel):
    class Meta(AeTmgModelMixin.Meta):
        verbose_name = "AE TMG Report"



# Generated by Django 4.0.5 on 2022-06-28 09:39

from django.db import migrations, models
from django.db.migrations import RunPython
from django.db.models import F


def func(apps, schema_editor):
    model_cls = apps.get_model("meta_subject", "studymedication")
    model_cls.objects.filter(refill_date__isnull=True).update(refill_date=F("report_datetime"))
    model_cls = apps.get_model("meta_subject", "historicalstudymedication")
    model_cls.objects.filter(refill_date__isnull=True).update(refill_date=F("report_datetime"))


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0107_auto_20220415_0043"),
    ]

    operations = [RunPython(func)]



# Generated by Django 3.2.11 on 2022-01-28 14:19

import uuid

import _socket
import django.contrib.sites.managers
import django.core.validators
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("edc_action_item", "0028_auto_20210203_0706"),
        ("meta_subject", "0094_auto_20211123_1645"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="action_identifier",
            field=models.CharField(db_index=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="action_item_reason",
            field=models.TextField(editable=False, null=True),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectvisitmissed",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=30, null=True),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="action_identifier",
            field=models.CharField(max_length=50, null=True, unique=True),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="action_item_reason",
            field=models.TextField(editable=False, null=True),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="parent_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="related_action_item",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="edc_action_item.actionitem",
            ),
        ),
        migrations.AddField(
            model_name="subjectvisitmissed",
            name="tracking_identifier",
            field=models.CharField(max_length=30, null=True, unique=True),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="contact_attempts_count",
            field=models.IntegerField(
                blank=True,
                help_text="Not including pre-appointment reminders. Multiple attempts on the same day count as a single attempt.",
                null=True,
                validators=[django.core.validators.MinValueValidator(1)],
                verbose_name="Number of attempts made to contact participantsince the expected appointment date",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="contact_attempts_count",
            field=models.IntegerField(
                blank=True,
                help_text="Not including pre-appointment reminders. Multiple attempts on the same day count as a single attempt.",
                null=True,
                validators=[django.core.validators.MinValueValidator(1)],
                verbose_name="Number of attempts made to contact participantsince the expected appointment date",
            ),
        ),
        migrations.CreateModel(
            name="HistoricalDietAndLifestyle",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(editable=False, max_length=50, null=True),
                ),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="COMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "diet_and_lifestyle",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="This response is not criteria for eligibility",
                        max_length=15,
                        null=True,
                        verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
                    ),
                ),
                (
                    "diet_and_lifestyle_duration",
                    models.IntegerField(
                        help_text="Report in minutes. This response is not criteria for eligibility",
                        null=True,
                        verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Clinic follow up: Examination",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="DietAndLifestyle",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(editable=False, max_length=50, null=True),
                ),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="COMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "diet_and_lifestyle",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="This response is not criteria for eligibility",
                        max_length=15,
                        null=True,
                        verbose_name="Has the participant received the META3 approved diet and lifetsyle counseling?",
                    ),
                ),
                (
                    "diet_and_lifestyle_duration",
                    models.IntegerField(
                        help_text="Report in minutes. This response is not criteria for eligibility",
                        null=True,
                        verbose_name="How much time was spent on the META3 approved diet and lifetsyle counseling with the patient?",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "Clinic follow up: Examination",
                "verbose_name_plural": "Clinic follow up: Examination",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AddIndex(
            model_name="dietandlifestyle",
            index=models.Index(
                fields=["subject_visit", "site", "id"],
                name="meta_subjec_subject_0c33b8_idx",
            ),
        ),
    ]



# Generated by Django 3.2.13 on 2022-09-14 02:18

import edc_visit_tracking.managers
from django.db import migrations

import meta_consent.models.subject_consent


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0013_auto_20220826_0406"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectconsent",
            managers=[
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
                ("objects", meta_consent.models.subject_consent.SubjectConsentManager()),
            ],
        ),
    ]



from django.db import models
from django.db.models import PROTECT
from edc_constants.choices import YES_NO
from edc_model.models import BaseUuidModel
from edc_utils import get_utcnow

from ..model_mixins import CrfModelMixin


class PregnancyUpdate(CrfModelMixin, BaseUuidModel):

    pregnancy_notification = models.ForeignKey(
        "meta_prn.pregnancynotification", on_delete=PROTECT
    )

    report_datetime = models.DateTimeField(
        verbose_name="Report Date and Time", default=get_utcnow
    )

    contact = models.CharField(
        verbose_name="Has the clinic received any updates on this pregnancy?",
        max_length=15,
        choices=YES_NO,
        help_text="If yes, please specify below",
    )

    comment = models.TextField(verbose_name="Comment / Updates", null=True)

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Pregnancy Update"
        verbose_name_plural = "Pregnancy Update"



from .field_lists import (
    calculated_fields,
    part_one_fields,
    part_three_comment_fields,
    part_three_fbg_fields,
    part_three_fields,
    part_three_glucose_fields,
    part_three_ogtt_fields,
    part_three_other_fields,
    part_three_pregnancy_fields,
    part_three_vitals_fields,
    part_two_fields,
)
from .screening_part_one_form import ScreeningPartOneForm
from .screening_part_three_form import ScreeningPartThreeForm
from .screening_part_two_form import ScreeningPartTwoForm
from .subject_refusal_form import SubjectRefusalForm
from .subject_screening_form import SubjectScreeningForm



# Generated by Django 4.0.5 on 2022-07-02 15:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0118_delivery_crf_status_delivery_crf_status_comments_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalstudymedication",
            name="roundup_divisible_by",
            field=models.IntegerField(default=32),
        ),
        migrations.AddField(
            model_name="studymedication",
            name="roundup_divisible_by",
            field=models.IntegerField(default=32),
        ),
    ]



# Generated by Django 4.0.5 on 2022-06-28 13:53

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0050_historicalscreeningpartone_agree_to_p3_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Not applicable if continuing to the second stage today",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Leave blank if continuing to the second stage today",
                null=True,
                verbose_name="Appointment date for second stage of screening (P3)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("N/A", "Decision pending / Not applicable")],
                default="N/A",
                help_text="Only applicable if the patient missed the appointment for the second stage of screening (P3), several attempts have been made to contact the patient, and the patient has not started P3. See above",
                max_length=15,
                verbose_name="Consider the patient 'lost to screening' for now?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Not applicable if continuing to the second stage today",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Leave blank if continuing to the second stage today",
                null=True,
                verbose_name="Appointment date for second stage of screening (P3)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("N/A", "Decision pending / Not applicable")],
                default="N/A",
                help_text="Only applicable if the patient missed the appointment for the second stage of screening (P3), several attempts have been made to contact the patient, and the patient has not started P3. See above",
                max_length=15,
                verbose_name="Consider the patient 'lost to screening' for now?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Not applicable if continuing to the second stage today",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Leave blank if continuing to the second stage today",
                null=True,
                verbose_name="Appointment date for second stage of screening (P3)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("N/A", "Decision pending / Not applicable")],
                default="N/A",
                help_text="Only applicable if the patient missed the appointment for the second stage of screening (P3), several attempts have been made to contact the patient, and the patient has not started P3. See above",
                max_length=15,
                verbose_name="Consider the patient 'lost to screening' for now?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Not applicable if continuing to the second stage today",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Leave blank if continuing to the second stage today",
                null=True,
                verbose_name="Appointment date for second stage of screening (P3)",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("N/A", "Decision pending / Not applicable")],
                default="N/A",
                help_text="Only applicable if the patient missed the appointment for the second stage of screening (P3), several attempts have been made to contact the patient, and the patient has not started P3. See above",
                max_length=15,
                verbose_name="Consider the patient 'lost to screening' for now?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="advised_to_fast",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="Not applicable if continuing to the second stage today",
                max_length=15,
                verbose_name="Has the patient been advised to return FASTED for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="agree_to_p3",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    (
                        "N/A",
                        "Not applicable, subject is not eligible based on the criteria above",
                    ),
                ],
                default="Yes",
                help_text="If patient is not continuing to the second stage today, advised to fast and provide a return appointment date below",
                max_length=15,
                verbose_name="Has the patient agreed to complete/return for the second stage of the screening?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="appt_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Leave blank if continuing to the second stage today",
                null=True,
                verbose_name="Appointment date for second stage of screening (P3)",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="p3_ltfu",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("N/A", "Decision pending / Not applicable")],
                default="N/A",
                help_text="Only applicable if the patient missed the appointment for the second stage of screening (P3), several attempts have been made to contact the patient, and the patient has not started P3. See above",
                max_length=15,
                verbose_name="Consider the patient 'lost to screening' for now?",
            ),
        ),
    ]



from django.contrib import admin
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.fieldset import crf_status_fieldset
from edc_qol.admin import sf12_fieldsets, sf12_radio_fields

from ..admin_site import meta_subject_admin
from ..forms import Sf12Form
from ..models import Sf12
from .modeladmin import CrfModelAdmin


@admin.register(Sf12, site=meta_subject_admin)
class Sf12Admin(CrfModelAdmin):

    form = Sf12Form

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        *sf12_fieldsets(),
        crf_status_fieldset,
        audit_fieldset_tuple,
    )

    radio_fields = sf12_radio_fields()



from __future__ import annotations

from copy import deepcopy
from datetime import datetime

from dateutil.relativedelta import relativedelta
from django.conf import settings
from django.contrib.sites.models import Site
from edc_appointment.constants import IN_PROGRESS_APPT, INCOMPLETE_APPT
from edc_appointment.tests.appointment_test_case_mixin import AppointmentTestCaseMixin
from edc_constants.constants import YES
from edc_facility.import_holidays import import_holidays
from edc_list_data.site_list_data import site_list_data
from edc_metadata import REQUIRED
from edc_metadata.models import CrfMetadata
from edc_randomization.site_randomizers import site_randomizers
from edc_sites import add_or_update_django_sites, get_sites_by_country
from edc_sites.tests.site_test_case_mixin import SiteTestCaseMixin
from edc_visit_tracking.constants import SCHEDULED
from model_bakery import baker

from meta_edc.meta_version import PHASE_THREE
from meta_pharmacy.prepare_meta_pharmacy import prepare_meta_pharmacy
from meta_sites import fqdn
from meta_subject.models import SubjectVisit
from meta_visit_schedule.constants import DAY1

from ..models import (
    ScreeningPartOne,
    ScreeningPartThree,
    ScreeningPartTwo,
    SubjectScreening,
)
from .options import (
    get_part_one_eligible_options,
    get_part_three_eligible_options,
    get_part_two_eligible_options,
    now,
)


class MetaTestCaseMixin(AppointmentTestCaseMixin, SiteTestCaseMixin):

    fqdn = fqdn

    default_sites = get_sites_by_country("tanzania")

    site_names = [s.name for s in default_sites]

    import_randomization_list = True

    sid_count_for_tests = 5

    @classmethod
    def setUpTestData(cls):
        import_holidays(test=True)
        add_or_update_django_sites(sites=get_sites_by_country("tanzania"))
        # site_randomizers._registry = {}
        if cls.import_randomization_list:
            # site_randomizers.register(RandomizerPhaseThree)
            randomizer_cls = site_randomizers.get(PHASE_THREE)
            randomizer_cls.import_list(
                verbose=False, sid_count_for_tests=cls.sid_count_for_tests
            )
        site_list_data.initialize()
        site_list_data.autodiscover()
        prepare_meta_pharmacy()

    def get_subject_screening(
        self,
        report_datetime: datetime | None = None,
        eligibility_datetime: datetime | None = None,
        gender: str | None = None,
        ethnicity: str | None = None,
        age_in_years: int | None = None,
    ):
        part_one_eligible_options = deepcopy(get_part_one_eligible_options())
        part_two_eligible_options = deepcopy(get_part_two_eligible_options())
        part_three_eligible_options = deepcopy(get_part_three_eligible_options())
        if report_datetime:
            part_one_eligible_options.update(report_datetime=report_datetime)
        part_one_eligible_options["age_in_years"] = (
            age_in_years or part_one_eligible_options["age_in_years"]
        )
        part_one_eligible_options["gender"] = gender or part_one_eligible_options["gender"]
        part_one_eligible_options["ethnicity"] = (
            ethnicity or part_one_eligible_options["ethnicity"]
        )
        part_one = ScreeningPartOne.objects.create(
            user_created="erikvw",
            user_modified="erikvw",
            **part_one_eligible_options,
        )
        screening_identifier = part_one.screening_identifier
        self.assertEqual(part_one.reasons_ineligible_part_one, None)
        self.assertEqual(part_one.eligible_part_one, YES)

        screening_part_two = ScreeningPartTwo.objects.get(
            screening_identifier=screening_identifier
        )
        for k, v in part_two_eligible_options.items():
            setattr(screening_part_two, k, v)
        screening_part_two.save()
        self.assertEqual(screening_part_two.reasons_ineligible_part_two, None)
        self.assertEqual(screening_part_two.eligible_part_two, YES)

        screening_part_three = ScreeningPartThree.objects.get(
            screening_identifier=screening_identifier
        )
        for k, v in part_three_eligible_options.items():
            setattr(screening_part_three, k, v)
        screening_part_three.save()
        self.assertEqual(screening_part_three.reasons_ineligible_part_three, None)
        self.assertEqual(screening_part_three.eligible_part_three, YES)

        subject_screening = SubjectScreening.objects.get(
            screening_identifier=screening_identifier
        )

        self.assertTrue(subject_screening.eligible)

        if eligibility_datetime:
            screening_part_three.eligibility_datetime = eligibility_datetime
            screening_part_three.save()
            subject_screening = SubjectScreening.objects.get(
                screening_identifier=screening_identifier
            )
        return subject_screening

    @staticmethod
    def get_subject_consent(subject_screening, consent_datetime=None, site_id=None):
        return baker.make_recipe(
            "meta_consent.subjectconsent",
            user_created="erikvw",
            user_modified="erikvw",
            screening_identifier=subject_screening.screening_identifier,
            initials=subject_screening.initials,
            gender=subject_screening.gender,
            dob=(now.date() - relativedelta(years=subject_screening.age_in_years)),
            site=Site.objects.get(id=site_id or settings.SITE_ID),
            consent_datetime=consent_datetime or subject_screening.report_datetime,
        )

    def get_subject_visit(
        self,
        visit_code: str | None = None,
        visit_code_sequence: int | None = None,
        subject_screening=None,
        subject_consent=None,
        reason: str | None = None,
        appt_datetime: datetime | None = None,
        gender: str | None = None,
        ethnicity: str | None = None,
        age_in_years: int | None = None,
        screening_datetime: datetime | None = None,
        eligibility_datetime: datetime | None = None,
    ):
        reason = reason or SCHEDULED
        subject_screening = subject_screening or self.get_subject_screening(
            gender=gender,
            ethnicity=ethnicity,
            age_in_years=age_in_years,
            report_datetime=screening_datetime,
            eligibility_datetime=eligibility_datetime,
        )
        subject_consent = subject_consent or self.get_subject_consent(subject_screening)
        options = dict(
            subject_identifier=subject_consent.subject_identifier,
            visit_code=visit_code or DAY1,
            visit_code_sequence=(
                visit_code_sequence if visit_code_sequence is not None else 0
            ),
            reason=reason,
        )
        if appt_datetime:
            options.update(appt_datetime=appt_datetime)
        appointment = self.get_appointment(**options)
        subject_visit = SubjectVisit(
            appointment=appointment,
            reason=SCHEDULED,
            report_datetime=appointment.appt_datetime,
        )
        subject_visit.save()
        subject_visit.refresh_from_db()
        return subject_visit

    @staticmethod
    def get_next_subject_visit(subject_visit):
        appointment = subject_visit.appointment
        appointment.appt_status = INCOMPLETE_APPT
        appointment.save()
        appointment.refresh_from_db()
        next_appointment = appointment.next_by_timepoint
        next_appointment.appt_status = IN_PROGRESS_APPT
        next_appointment.save()
        subject_visit = SubjectVisit(
            appointment=next_appointment,
            reason=SCHEDULED,
            report_datetime=next_appointment.appt_datetime,
            visit_code=next_appointment.visit_code,
            visit_code_sequence=next_appointment.visit_code_sequence,
        )
        subject_visit.save()
        subject_visit.refresh_from_db()
        return subject_visit

    @staticmethod
    def get_crf_metadata(subject_visit):
        return CrfMetadata.objects.filter(
            subject_identifier=subject_visit.subject_identifier,
            visit_code=subject_visit.visit_code,
            visit_code_sequence=subject_visit.visit_code_sequence,
            entry_status=REQUIRED,
        )



# Generated by Django 2.2.6 on 2019-10-24 07:00

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("meta_subject", "0004_auto_20191022_0134")]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="complications",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="followup",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="followupvitals",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomics",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="malariarapidtest",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="medicationadherence",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectrequisition",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisit",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.AlterField(
            model_name="urinedipsticktest",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
    ]



from django.db import models
from edc_constants.choices import YES_NO
from edc_model.models import BaseUuidModel

from ..model_mixins import CrfModelMixin


class OtherArvRegimens(CrfModelMixin, BaseUuidModel):
    has_other_regimens = models.CharField(
        verbose_name=(
            "Are there additional ARV regimens to report "
            "NOT reported on the Patient History CRF?"
        ),
        max_length=15,
        choices=YES_NO,
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Other ARV Regimens"
        verbose_name_plural = "Other ARV Regimens"



# Generated by Django 4.0.5 on 2022-06-27 14:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_screening", "0045_historicalscreeningpartone_contact_number_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="hba1c_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Date and time of result.",
                null=True,
                verbose_name="HbA1c date and time",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="hba1c_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Date and time of result.",
                null=True,
                verbose_name="HbA1c date and time",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="hba1c_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Date and time of result.",
                null=True,
                verbose_name="HbA1c date and time",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="hba1c_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Date and time of result.",
                null=True,
                verbose_name="HbA1c date and time",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="hba1c_datetime",
            field=models.DateTimeField(
                blank=True,
                help_text="Date and time of result.",
                null=True,
                verbose_name="HbA1c date and time",
            ),
        ),
    ]



from django.db import models
from edc_action_item.models import ActionModelMixin
from edc_identifier.model_mixins import NonUniqueSubjectIdentifierFieldMixin
from edc_model.models import BaseUuidModel
from edc_pharmacy.models import Medication
from edc_sites.models import SiteModelMixin
from edc_utils import get_utcnow

from meta_pharmacy.constants import METFORMIN

from ..choices import WITHDRAWAL_STUDY_MEDICATION_REASONS
from ..constants import OFFSTUDY_MEDICATION_ACTION


class OffStudyMedication(
    NonUniqueSubjectIdentifierFieldMixin,
    SiteModelMixin,
    ActionModelMixin,
    BaseUuidModel,
):

    action_name = OFFSTUDY_MEDICATION_ACTION

    offschedule_compare_dates_as_datetimes = False

    report_datetime = models.DateTimeField(
        verbose_name="Report Date and Time", default=get_utcnow
    )

    medications = models.ManyToManyField(Medication, limit_choices_to={"name": METFORMIN})

    stop_date = models.DateField(
        verbose_name="Date decision to stop study medication",
    )

    last_dose_date = models.DateField(
        verbose_name="Date of last known dose",
    )

    reason = models.CharField(
        verbose_name="Reason for stopping study medication",
        max_length=25,
        choices=WITHDRAWAL_STUDY_MEDICATION_REASONS,
    )

    reason_other = models.TextField(
        verbose_name="If other, please specify ...",
        null=True,
        blank=True,
    )

    comment = models.TextField(
        verbose_name="Any additional comments",
        null=True,
        blank=True,
    )

    class Meta(BaseUuidModel.Meta):
        verbose_name = "Withdrawal of Study Drug"
        verbose_name_plural = "Withdrawal of Study Drug"
